@@ -8,7 +8,7 @@ from aiohttp import Payload
 from aiohttp.web_response import Response
 from dynamic_types.class_name import _prepare_class_name
 from dynamic_types.create import create_type, create_dataclass
-from init_helpers import custom_dumps
+from init_helpers import custom_dumps, is_instance
 from init_helpers.dict_to_dataclass import dict_to_dataclass, convert_to_type
 from yarl import URL
 
@@ -109,7 +109,7 @@ class JsonableAnswer(Answer):
 
     def convert_payload(self, payload):
         if payload_type := self.get_class_payload_type():
-            if isinstance(payload, payload_type):
+            if is_instance(payload, payload_type):
                 return payload
 
             if dataclasses.is_dataclass(payload_type):
